Documentation
¶
Index ¶
- Variables
- func Bool(b bool) *bool
- func Float32(f float32) *float32
- func Float64(f float64) *float64
- func Int(i int) *int
- func Int64(i int64) *int64
- func Pointer[T any](v T) *T
- func String(s string) *string
- type APICredentials
- func (s *APICredentials) Create(ctx context.Context, organizationID string, ...) (*operations.V1APICredentialsCreateAPICredentialResponse, error)
- func (s *APICredentials) Delete(ctx context.Context, organizationID string, apiCredentialID string, ...) (*operations.V1APICredentialsDeleteAPICredentialResponse, error)
- func (s *APICredentials) Get(ctx context.Context, organizationID string, apiCredentialID string, ...) (*operations.V1APICredentialsGetAPICredentialResponse, error)
- func (s *APICredentials) List(ctx context.Context, organizationID string, opts ...operations.Option) (*operations.V1APICredentialsListAPICredentialsResponse, error)
- func (s *APICredentials) Update(ctx context.Context, organizationID string, apiCredentialID string, ...) (*operations.V1APICredentialsUpdateAPICredentialResponse, error)
- type CriblMgmtPlane
- type HTTPClient
- type Health
- type SDKOption
- func WithClient(client HTTPClient) SDKOption
- func WithRetryConfig(retryConfig retry.Config) SDKOption
- func WithSecurity(security components.Security) SDKOption
- func WithSecuritySource(security func(context.Context) (components.Security, error)) SDKOption
- func WithServerIndex(serverIndex int) SDKOption
- func WithServerURL(serverURL string) SDKOption
- func WithTemplatedServerURL(serverURL string, params map[string]string) SDKOption
- func WithTimeout(timeout time.Duration) SDKOption
- type Workspaces
- func (s *Workspaces) Create(ctx context.Context, organizationID string, ...) (*operations.V1WorkspacesCreateWorkspaceResponse, error)
- func (s *Workspaces) Delete(ctx context.Context, organizationID string, workspaceID string, ...) (*operations.V1WorkspacesDeleteWorkspaceResponse, error)
- func (s *Workspaces) Get(ctx context.Context, organizationID string, workspaceID string, ...) (*operations.V1WorkspacesGetWorkspaceResponse, error)
- func (s *Workspaces) List(ctx context.Context, organizationID string, opts ...operations.Option) (*operations.V1WorkspacesListWorkspacesResponse, error)
- func (s *Workspaces) Update(ctx context.Context, organizationID string, workspaceID string, ...) (*operations.V1WorkspacesUpdateWorkspaceResponse, error)
Constants ¶
This section is empty.
Variables ¶
var ServerList = []string{
"https://gateway.cribl.cloud",
}
ServerList contains the list of servers available to the SDK
Functions ¶
Types ¶
type APICredentials ¶
type APICredentials struct {
// contains filtered or unexported fields
}
APICredentials - Operations related to API credentials
func (*APICredentials) Create ¶
func (s *APICredentials) Create(ctx context.Context, organizationID string, apiCredentialCreateRequestDTO components.APICredentialCreateRequestDTO, opts ...operations.Option) (*operations.V1APICredentialsCreateAPICredentialResponse, error)
Create an API Credential Create a new API Credential for the specified Organization.
func (*APICredentials) Delete ¶
func (s *APICredentials) Delete(ctx context.Context, organizationID string, apiCredentialID string, opts ...operations.Option) (*operations.V1APICredentialsDeleteAPICredentialResponse, error)
Delete an API Credential Delete the specified API Credential.
func (*APICredentials) Get ¶
func (s *APICredentials) Get(ctx context.Context, organizationID string, apiCredentialID string, opts ...operations.Option) (*operations.V1APICredentialsGetAPICredentialResponse, error)
Get an API Credential Get the specified API Credential.
func (*APICredentials) List ¶
func (s *APICredentials) List(ctx context.Context, organizationID string, opts ...operations.Option) (*operations.V1APICredentialsListAPICredentialsResponse, error)
List API Credentials for an Organization Get a list of all API Credentials for the specified Organization.
func (*APICredentials) Update ¶
func (s *APICredentials) Update(ctx context.Context, organizationID string, apiCredentialID string, apiCredentialUpdateRequestDTO components.APICredentialUpdateRequestDTO, opts ...operations.Option) (*operations.V1APICredentialsUpdateAPICredentialResponse, error)
Update an API Credential Update the specified API Credential.
type CriblMgmtPlane ¶
type CriblMgmtPlane struct {
SDKVersion string
// Operations related to application health status
Health *Health
// Operations related to API credentials
APICredentials *APICredentials
// Operations related to Workspaces
Workspaces *Workspaces
// contains filtered or unexported fields
}
CriblMgmtPlane - Cribl.Cloud Public API: Public API for the Cribl.Cloud platform. Powers the Speakeasy SDK.
func New ¶
func New(opts ...SDKOption) *CriblMgmtPlane
New creates a new instance of the SDK with the provided options
type HTTPClient ¶
HTTPClient provides an interface for supplying the SDK with a custom HTTP client
type Health ¶
type Health struct {
// contains filtered or unexported fields
}
Health - Operations related to application health status
func (*Health) Get ¶
func (s *Health) Get(ctx context.Context, opts ...operations.Option) (*operations.GetHealthStatusResponse, error)
Get the health status of the application
type SDKOption ¶
type SDKOption func(*CriblMgmtPlane)
func WithClient ¶
func WithClient(client HTTPClient) SDKOption
WithClient allows the overriding of the default HTTP client used by the SDK
func WithRetryConfig ¶
func WithSecurity ¶
func WithSecurity(security components.Security) SDKOption
WithSecurity configures the SDK to use the provided security details
func WithSecuritySource ¶
WithSecuritySource configures the SDK to invoke the Security Source function on each method call to determine authentication
func WithServerIndex ¶
WithServerIndex allows the overriding of the default server by index
func WithServerURL ¶
WithServerURL allows providing an alternative server URL
func WithTemplatedServerURL ¶
WithTemplatedServerURL allows the overriding of the default server URL with a templated URL populated with the provided parameters
func WithTimeout ¶
WithTimeout Optional request timeout applied to each operation
type Workspaces ¶
type Workspaces struct {
// contains filtered or unexported fields
}
Workspaces - Operations related to Workspaces
func (*Workspaces) Create ¶
func (s *Workspaces) Create(ctx context.Context, organizationID string, workspaceCreateRequestDTO components.WorkspaceCreateRequestDTO, opts ...operations.Option) (*operations.V1WorkspacesCreateWorkspaceResponse, error)
Create a Workspace in the specified Organization Create a new Workspace in the specified Organization.
func (*Workspaces) Delete ¶
func (s *Workspaces) Delete(ctx context.Context, organizationID string, workspaceID string, opts ...operations.Option) (*operations.V1WorkspacesDeleteWorkspaceResponse, error)
Delete a Workspace Delete the specified Workspace in the specified Organization.
func (*Workspaces) Get ¶
func (s *Workspaces) Get(ctx context.Context, organizationID string, workspaceID string, opts ...operations.Option) (*operations.V1WorkspacesGetWorkspaceResponse, error)
Get a Workspace Get the specified Workspace.
func (*Workspaces) List ¶
func (s *Workspaces) List(ctx context.Context, organizationID string, opts ...operations.Option) (*operations.V1WorkspacesListWorkspacesResponse, error)
List all Workspaces for the specified Organization Get a list of all Workspaces for the specified Organization.
func (*Workspaces) Update ¶
func (s *Workspaces) Update(ctx context.Context, organizationID string, workspaceID string, workspacePatchRequestDTO components.WorkspacePatchRequestDTO, opts ...operations.Option) (*operations.V1WorkspacesUpdateWorkspaceResponse, error)
Update a Workspace Update the specified Workspace.